@@ -3,6 +3,6 @@ function (...)
 {
     x = cbind(...)
     if(!is.numeric(x))
-        stop("Input should by numeric.")
+        stop("Input should be numeric.")
     do.call("order", lapply(1:ncol(x), function(i) x[, i]))
 }
